Documentation
=============

This is the documentation for navo.
This package is a collection of utilities to facilitate access to Virtual
Observatory services., largely built on top on the PyVO package.  These
utilities are written as a part of the NASA Astronomical Virtual Observatories
(NAVO).

.. toctree::
  :maxdepth: 2

  navo/index.rst

.. note:: The layout of this directory is simply a suggestion.  To follow
          traditional practice, do *not* edit this page, but instead place
          all documentation for the package inside ``navo/``.
          You can follow this practice or choose your own layout.
